package cn.bootx.platform.daxpay.controller;

import cn.bootx.platform.common.core.rest.PageResult;
import cn.bootx.platform.common.core.rest.Res;
import cn.bootx.platform.common.core.rest.ResResult;
import cn.bootx.platform.common.core.rest.dto.LabelValue;
import cn.bootx.platform.common.core.rest.param.PageParam;
import cn.bootx.platform.daxpay.core.merchant.service.MerchantInfoService;
import cn.bootx.platform.daxpay.dto.merchant.MerchantInfoDto;
import cn.bootx.platform.daxpay.param.merchant.MerchantInfoParam;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 商户
 *
 * @author xxm
 * @since 2023-05-17
 */
@Tag(name = "商户")
@RestController
@RequestMapping("/merchant")
@RequiredArgsConstructor
public class MerchantInfoController {

    private final MerchantInfoService merchantInfoService;

    @Operation(summary = "添加")
    @PostMapping(value = "/add")
    public ResResult<Void> add(@RequestBody MerchantInfoParam param) {
        merchantInfoService.add(param);
        return Res.ok();
    }

    @Operation(summary = "修改")
    @PostMapping(value = "/update")
    public ResResult<Void> update(@RequestBody MerchantInfoParam param) {
        merchantInfoService.update(param);
        return Res.ok();
    }

    @Operation(summary = "下拉列表(所有)")
    @GetMapping("/dropdown")
    public ResResult<List<LabelValue>> dropdown() {
        return Res.ok(merchantInfoService.dropdown());
    }

    @Operation(summary = "下拉列表(可用状态的)")
    @GetMapping("/dropdownNormal")
    public ResResult<List<LabelValue>> dropdownNormal() {
        return Res.ok(merchantInfoService.dropdownNormal());
    }

    @Operation(summary = "删除")
    @DeleteMapping(value = "/delete")
    public ResResult<Void> delete(Long id) {
        merchantInfoService.delete(id);
        return Res.ok();
    }

    @Operation(summary = "通过ID查询")
    @GetMapping(value = "/findById")
    public ResResult<MerchantInfoDto> findById(Long id) {
        return Res.ok(merchantInfoService.findById(id));
    }

    @Operation(summary = "查询所有")
    @GetMapping(value = "/findAll")
    public ResResult<List<MerchantInfoDto>> findAll() {
        return Res.ok(merchantInfoService.findAll());
    }

    @Operation(summary = "分页查询")
    @GetMapping(value = "/page")
    public ResResult<PageResult<MerchantInfoDto>> page(PageParam pageParam, MerchantInfoParam merchantInfoParam) {
        return Res.ok(merchantInfoService.page(pageParam, merchantInfoParam));
    }

}
